from setuptools import setup
 
setup(
     name = 'sheetrocks',         
     packages = ['sheetrocks'],   
     version = '0.2',      
     license='MIT',        
     description = 'Package to support custom python formulas in SheetRocks',
     author = 'Anthony Garvan',                  
     author_email = 'tony@sheet.rocks',
)        